function [J_avg, J_std] = EvaluateCostAvg(theta,scenario,n_avg)
% Evaluation of cost function N_AVG times and take the average.
%
% Input:
%   theta           Parameter value, column vector
%   scenario        The considered scenario: imperfect model or imperfect
%                   (noisy) state measurements
%                   Choices:
%                       perturbedModel
%                       imperfectState
%   n_avg           Number of individual cost evaluations that are
%                   averaged.
%
% Output:
%   J_avg           cost averaged over n_avg evaluations, 
%                   in paper notation: $\hat{J}_{n_avg}(\theta)$
%   J_std           standard deviation of cost evaluations
%
% --
% Self-tuning LQR, Trimpe et al. IFAC World Congress 2014 paper
%
% Copyright:
% Sebastian Trimpe
% Max-Planck-Institute for Intelligent Systems
% Autonomous Motion Department
% strimpe(at)tuebingen.mpg.de
%
% Revision history
% [13.11.13]   first version to be published


Jvec = zeros(n_avg,1);

for i=1:n_avg
    Jvec(i) = EvaluateCost(theta,scenario);
end;

J_avg = mean(Jvec);
J_std = std(Jvec);